@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,8 +19,6 @@
  *
  */
 
-
-
 package com.openexchange.fileitem.impl;
 
 import static org.apache.commons.lang.StringUtils.isEmpty;
@@ -36,6 +34,7 @@ import java.util.Set;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.function.Consumer;
 import org.apache.commons.collections.BidiMap;
+import org.apache.commons.lang.ArrayUtils;
 import org.json.JSONObject;
 import com.openexchange.annotation.NonNull;
 import com.openexchange.annotation.Nullable;
@@ -113,7 +112,9 @@ public class FileItemService implements IFileItemService {
      */
     @Override
     public DatabaseType getDatabaseType() {
-        return m_database.getDatabaseType();
+        return hasDatabase() ?
+            m_database.getDatabaseType() :
+                DatabaseType.MYSQL;
     }
 
     /* (non-Javadoc)
@@ -125,7 +126,9 @@ public class FileItemService implements IFileItemService {
             throw new FileItemException("FileItemService not able to register group with empty groupId");
         }
 
-        m_database.registerGroup(groupId, keyN);
+        if (hasDatabase()) {
+            m_database.registerGroup(groupId, keyN);
+        }
     }
 
     /* (non-Javadoc)
@@ -137,9 +140,12 @@ public class FileItemService implements IFileItemService {
             throw new FileItemException("Invalid groupId");
         }
 
-        final Set<String> keySet = m_database.getCustomPropertyKeys(groupId);
+        if (hasDatabase()) {
+            final Set<String> keySet = m_database.getCustomPropertyKeys(groupId);
+            return keySet.toArray(new String[keySet.size()]);
+        }
 
-        return keySet.toArray(new String[keySet.size()]);
+        return ArrayUtils.EMPTY_STRING_ARRAY;
     }
 
     /* (non-Javadoc)
@@ -153,7 +159,9 @@ public class FileItemService implements IFileItemService {
             throw new FileItemException("Invalid key");
         }
 
-        return m_database.hasCustomPropertyKey(groupId, key);
+        return hasDatabase() ?
+            m_database.hasCustomPropertyKey(groupId, key) :
+                false;
     }
 
     /* (non-Javadoc)
@@ -165,7 +173,9 @@ public class FileItemService implements IFileItemService {
             throw new FileItemException("Invalid groupId");
         }
 
-        return m_database.getUserData(groupId);
+        return hasDatabase() ?
+            m_database.getUserData(groupId) :
+                new JSONObject();
     }
 
     /* (non-Javadoc)
@@ -177,7 +187,7 @@ public class FileItemService implements IFileItemService {
             throw new FileItemException("Invalid groupId");
         }
 
-        return (null != userData) ?
+        return (hasDatabase() && (null != userData)) ?
             m_database.setUserData(groupId, userData) :
                 false;
     }
@@ -189,7 +199,7 @@ public class FileItemService implements IFileItemService {
      */
     @Override
     public boolean containsGroup(final String groupId) throws FileItemException {
-        return (FileItemUtils.isValid(groupId)) ?
+        return (hasDatabase() && FileItemUtils.isValid(groupId)) ?
             m_database.contains(groupId) :
                 false;
     }
@@ -199,7 +209,7 @@ public class FileItemService implements IFileItemService {
      */
     @Override
     public boolean containsSubGroup(final String groupId, final String subGroupId) throws FileItemException {
-        return (FileItemUtils.isValid(groupId) && FileItemUtils.isValid(subGroupId)) ?
+        return (hasDatabase() && FileItemUtils.isValid(groupId) && FileItemUtils.isValid(subGroupId)) ?
             m_database.contains(groupId, subGroupId) :
                 false;
     }
@@ -209,7 +219,7 @@ public class FileItemService implements IFileItemService {
      */
     @Override
     public boolean contains(final String groupId, final String subGroupId, final String fileId) throws FileItemException {
-        return (FileItemUtils.isValid(groupId) && FileItemUtils.isValid(subGroupId) && FileItemUtils.isValid(fileId)) ?
+        return (hasDatabase() && FileItemUtils.isValid(groupId) && FileItemUtils.isValid(subGroupId) && FileItemUtils.isValid(fileId)) ?
             m_database.contains(groupId, subGroupId) :
                 false;
     }
@@ -223,7 +233,7 @@ public class FileItemService implements IFileItemService {
     public IFileItem get(String groupId, String subGroupId, String fileId) throws FileItemException {
         FileItem ret = implGetCheckedFileItem(implCreateFileItem(groupId, subGroupId, fileId));
 
-        if (null != ret) {
+        if (hasDatabase() && (null != ret)) {
             final FileStoreData fileStoreData = m_database.getFileStoreData(ret);
 
             if (FileItemUtils.isValid(fileStoreData)) {
@@ -241,7 +251,7 @@ public class FileItemService implements IFileItemService {
      */
     @Override
     public IFileItem[] get(final String groupId, final String subGroupId) throws FileItemException {
-        return (FileItemUtils.isValid(groupId) && FileItemUtils.isValid(subGroupId)) ?
+        return (hasDatabase() && FileItemUtils.isValid(groupId) && FileItemUtils.isValid(subGroupId)) ?
             m_database.getFileItems(groupId, subGroupId) :
                 new FileItem[0];
     }
@@ -251,7 +261,7 @@ public class FileItemService implements IFileItemService {
      */
     @Override
     public IFileItem[] get(final String groupId, final Properties properties) throws FileItemException {
-        return (FileItemUtils.isValid(groupId) && (null != properties) && (properties.size() > 0)) ?
+        return (hasDatabase() && FileItemUtils.isValid(groupId) && (null != properties) && (properties.size() > 0)) ?
             m_database.getFileItems(groupId, properties) :
                 new FileItem[0];
     }
@@ -263,7 +273,7 @@ public class FileItemService implements IFileItemService {
      */
     @Override
     public long getSubGroupCount(final String groupId) throws FileItemException {
-        return FileItemUtils.isValid(groupId) ?
+        return (hasDatabase() && FileItemUtils.isValid(groupId)) ?
             m_database.getSubGroupCount(groupId) :
                 0;
     }
@@ -273,9 +283,9 @@ public class FileItemService implements IFileItemService {
      */
     @Override
     public String[] getSubGroups(final String groupId) throws FileItemException {
-        return FileItemUtils.isValid(groupId) ?
+        return (hasDatabase() && FileItemUtils.isValid(groupId)) ?
             m_database.getSubGroupIds(groupId) :
-                new String[0];
+                ArrayUtils.EMPTY_STRING_ARRAY;
     }
 
     /* (non-Javadoc)
@@ -283,9 +293,9 @@ public class FileItemService implements IFileItemService {
      */
     @Override
     public String[] getSubGroupsBy(final String groupId, @Nullable final String whereClause, @Nullable String limitClause) throws FileItemException {
-        return (isNotEmpty(whereClause) || isNotEmpty(limitClause)) ?
+        return (hasDatabase() && isNotEmpty(whereClause) || isNotEmpty(limitClause)) ?
             m_database.getSubGroupIdsBy(groupId, whereClause, limitClause) :
-                new String[0];
+                ArrayUtils.EMPTY_STRING_ARRAY;
     }
 
     /* (non-Javadoc)
@@ -293,7 +303,7 @@ public class FileItemService implements IFileItemService {
      */
     @Override
     public long getSubGroupsBy(String groupId, String whereClause, String limitClause, Consumer<ISubGroup> subGroupConsumer) throws FileItemException {
-        return FileItemUtils.isValid(groupId) ?
+        return (hasDatabase() && FileItemUtils.isValid(groupId)) ?
             m_database.getSubGroupsBy(groupId, whereClause, limitClause, subGroupConsumer) :
                 0;
     }
@@ -303,7 +313,9 @@ public class FileItemService implements IFileItemService {
      */
     @Override
     public long getGroupCount() throws FileItemException {
-        return m_database.getGroupCount();
+        return hasDatabase() ?
+            m_database.getGroupCount() :
+                0;
     }
 
     /* (non-Javadoc)
@@ -311,7 +323,9 @@ public class FileItemService implements IFileItemService {
      */
     @Override
     public String[] getGroups() throws FileItemException {
-        return m_database.getGroupIds();
+        return hasDatabase() ?
+            m_database.getGroupIds() :
+                ArrayUtils.EMPTY_STRING_ARRAY;
     }
 
     // -------------------------------------------------------------------------
@@ -321,7 +335,9 @@ public class FileItemService implements IFileItemService {
      */
     @Override
     public long getGroupLength(String groupId) throws FileItemException {
-        return m_database.getGroupLength(groupId);
+        return hasDatabase() ?
+            m_database.getGroupLength(groupId) :
+                0;
     }
 
     /* (non-Javadoc)
@@ -329,7 +345,9 @@ public class FileItemService implements IFileItemService {
      */
     @Override
     public long getGroupLength(String groupId, Properties properties) throws FileItemException {
-        return m_database.getGroupLength(groupId, null, properties);
+        return hasDatabase() ?
+            m_database.getGroupLength(groupId, null, properties) :
+                0;
     }
 
     /* (non-Javadoc)
@@ -337,7 +355,9 @@ public class FileItemService implements IFileItemService {
      */
     @Override
     public long getSubGroupLength(String groupId, String subGroupId) throws FileItemException {
-        return m_database.getGroupLength(groupId, subGroupId, null);
+        return hasDatabase() ?
+            m_database.getGroupLength(groupId, subGroupId, null) :
+                0;
     }
 
     /* (non-Javadoc)
@@ -345,7 +365,9 @@ public class FileItemService implements IFileItemService {
      */
     @Override
     public long getSubGroupLength(String groupId, String subGroupId, Properties properties) throws FileItemException {
-        return m_database.getGroupLength(groupId, subGroupId, properties);
+        return hasDatabase() ?
+            m_database.getGroupLength(groupId, subGroupId, properties) :
+                0;
     }
 
     // -------------------------------------------------------------------------
@@ -358,7 +380,7 @@ public class FileItemService implements IFileItemService {
         final FileItem fileItem = implGetCheckedFileItem(iFileItem);
         boolean ret = false;
 
-        if (null != fileItem) {
+        if (hasDatabase() && (null != fileItem)) {
             final String fileItemKey = fileItem.getKey();
 
             try {
@@ -409,7 +431,7 @@ public class FileItemService implements IFileItemService {
     public int remove(final String groupId, final Properties properties) throws FileItemException {
         int ret = 0;
 
-        if (isNotEmpty(groupId) && (null != properties) && (properties.size() > 0)) {
+        if (hasDatabase() && isNotEmpty(groupId) && (null != properties) && (properties.size() > 0)) {
             final List<FileStoreData> deletedFileStoreDataList = new ArrayList<>(8192);
             final int deletedEntries = m_database.deleteByProperties(groupId, properties, deletedFileStoreDataList);
 
@@ -428,7 +450,7 @@ public class FileItemService implements IFileItemService {
     public int removeSubGroup(final String groupId, final String subGroupId) throws FileItemException {
         int ret = 0;
 
-        if (FileItemUtils.isValid(groupId) && FileItemUtils.isValid(subGroupId)) {
+        if (hasDatabase() && FileItemUtils.isValid(groupId) && FileItemUtils.isValid(subGroupId)) {
             final List<FileStoreData> deletedFileStoreDataList = new ArrayList<>(8192);
             final int deletedEntries = m_database.deleteByGroupSubgroup(groupId, subGroupId, deletedFileStoreDataList);
 
@@ -447,7 +469,7 @@ public class FileItemService implements IFileItemService {
     public int removeSubGroups(final String groupId, final String[] subGroupIds) throws FileItemException {
         int ret = 0;
 
-        if (FileItemUtils.isValid(groupId) && FileItemUtils.isValid(subGroupIds)) {
+        if (hasDatabase() && FileItemUtils.isValid(groupId) && FileItemUtils.isValid(subGroupIds)) {
             final List<FileStoreData> deletedFileStoreDataList = new ArrayList<>(8192);
             final String[] targetSubGroupIds = Arrays.asList(subGroupIds).stream().
                                                    filter(FileItemUtils::isValid).
@@ -471,7 +493,7 @@ public class FileItemService implements IFileItemService {
     public int removeGroup(final String groupId) throws FileItemException {
         int ret = 0;
 
-        if (FileItemUtils.isValid(groupId)) {
+        if (hasDatabase() && FileItemUtils.isValid(groupId)) {
             final List<FileStoreData> deletedFileStoreDataList = new ArrayList<>(8192);
             final int deletedEntries = m_database.deleteByGroupSubgroup(groupId, null, deletedFileStoreDataList);
 
@@ -567,6 +589,13 @@ public class FileItemService implements IFileItemService {
 
     // - Package internal API --------------------------------------------------
 
+    /**
+     * @return
+     */
+    public boolean hasDatabase() {
+        return (null != m_database);
+    }
+
     /**
      *
      */
