@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,8 +19,6 @@
  *
  */
 
-
-
 package com.openexchange.imageconverter.server.osgi;
 
 import java.util.concurrent.Executors;
@@ -34,10 +32,13 @@ import com.openexchange.config.ConfigurationService;
 import com.openexchange.html.HtmlService;
 import com.openexchange.imageconverter.api.IImageConverter;
 import com.openexchange.imageconverter.api.ImageConverterException;
+import com.openexchange.imageconverter.impl.ImageConverter;
 import com.openexchange.imageconverter.server.rest.ImageConverterServerRest;
 import com.openexchange.osgi.HousekeepingActivator;
 
-//=============================================================================
+/**
+ * ImageConverterServerActivator
+ */
 public class ImageConverterServerActivator extends HousekeepingActivator {
     public ImageConverterServerActivator() {
         super();
@@ -81,7 +82,9 @@ public class ImageConverterServerActivator extends HousekeepingActivator {
 
                     if (monitor != null) {
                         Executors.newSingleThreadExecutor().execute(() -> {
-                            registerService(ImageConverterServerRest.class, m_imageConverterServerRest = new ImageConverterServerRest(self, imageConverter));
+                            m_imageConverterServerRest = new ImageConverterServerRest(self, (ImageConverter) imageConverter);
+                            registerService(ImageConverterServerRest.class, m_imageConverterServerRest);
+
                             LOG.info(SERVICE_NAME + " registered REST service");
                         });
 
