@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,8 +19,6 @@
  *
  */
 
-
-
 package com.openexchange.imageconverter.impl;
 
 import static com.openexchange.imageconverter.impl.ImageConverterUtils.LOG;
@@ -37,8 +35,11 @@ import java.util.List;
 import java.util.Properties;
 import java.util.Set;
 import java.util.concurrent.atomic.AtomicBoolean;
+import org.apache.commons.io.FilenameUtils;
 import org.apache.commons.io.IOUtils;
 import org.apache.commons.lang.ArrayUtils;
+import org.apache.commons.lang.StringUtils;
+import org.json.JSONObject;
 import com.google.common.base.Throwables;
 import com.openexchange.annotation.NonNull;
 import com.openexchange.annotation.Nullable;
@@ -187,77 +188,95 @@ public final class ImageConverter implements IImageConverter {
         return m_imageProcessor.getStatus();
     }
 
-    // - IImageConverter ----------------------------------------------------------
-
-    /*
-     * (non-Javadoc)
-     *
-     * @see com.openexchange.imageconverter.api.IImageConverter#getImage(java.lang.String, java.lang.String, java.lang.String)
+    /**
+     * @param imageKey
+     * @param requestFormat
+     * @param jsonInfo
+     * @param context
+     * @return
+     * @throws ImageConverterException
      */
     @Override
-    public InputStream getImage(final String imageKey, final String requestFormat, final String... context) throws ImageConverterException {
+    public InputStream getImage(
+        final String imageKey,
+        final String requestFormat,
+        final String fileName,
+        final String... context) throws ImageConverterException {
+
         final long requestStartTime = System.currentTimeMillis();
 
         if (LOG.isTraceEnabled()) {
             implTrace(ImageConverterUtils.STR_BUILDER().
-                append("#getImage called (imageKey / requestFormat): ").
-                append(imageKey).append(" / ").append(requestFormat).toString(),
+                append("#getImage called (imageKey / requestFormat / fileName): ").
+                append(imageKey).append(" / ").append(requestFormat).append(" / ").append(fileName).toString(),
                 context);
         }
 
-        // no cache operation possible ATM => return null
-        if ((null == m_queue) || !m_cacheStatusOK.get()) {
-            return null;
-        }
-
         ImageConverterStatus status = (isNotEmpty(imageKey) && isNotEmpty(requestFormat)) ?
             ImageConverterStatus.OK :
                 ImageConverterStatus.KEY_NOT_VALID;
 
-        try (final MetadataImage metadataImage = m_queue.getMetadataImage(imageKey, requestFormat)) {
-            InputStream ret = (null != metadataImage) ?
-                metadataImage.getImageInputStream(true) :
-                    null;
+        try {
+            // no cache operation possible ATM => return null
+            if ((null == m_queue) || !m_cacheStatusOK.get()) {
+                status = ImageConverterStatus.CACHE_NOT_AVAILABLE;
+                return null;
+            } else {
+                try (final MetadataImage metadataImage = m_queue.getMetadataImage(imageKey, requestFormat, fileName)) {
+                    InputStream ret = (null != metadataImage) ?
+                        metadataImage.getImageInputStream(true) :
+                            null;
 
-            if (null == ret) {
-                status = ImageConverterStatus.KEY_NOT_AVAILABLE;
+                    if (null == ret) {
+                        status = ImageConverterStatus.KEY_NOT_AVAILABLE;
+                    }
+
+                    return ret;
+                } catch (IOException | ImageConverterException e) {
+                    LOG.trace("IC exception while getting MetadataImage", e);
+
+                    status = ImageConverterStatus.GENERAL_ERROR;
+                    throw new ImageConverterException("IC error while getting MetadataImage: " + imageKey, e);
+                }
             }
-
-            return ret;
-        } catch (IOException | ImageConverterException e) {
-            LOG.trace("IC exception while getting MetadataImage", e);
-
-            status = ImageConverterStatus.GENERAL_ERROR;
-            throw new ImageConverterException("IC error while getting MetadataImage: " + imageKey, e);
         } finally {
             implFinishRequest(RequestType.GET, requestStartTime, status);
         }
     }
 
-    /* (non-Javadoc)
-     * @see com.openexchange.imageconverter.api.IImageConverter#getMetadata(java.lang.String, java.lang.String[])
+    /**
+     * @param imageKey
+     * @param jsonInfo
+     * @param context
+     * @return
+     * @throws ImageConverterException
      */
     @Override
-    public IMetadata getMetadata(String imageKey, String... context) throws ImageConverterException {
+    public IMetadata getMetadata(
+        String imageKey,
+        String fileName,
+        String... context) throws ImageConverterException {
+
         final long requestStartTime = System.currentTimeMillis();
 
         if (LOG.isTraceEnabled()) {
             implTrace(ImageConverterUtils.STR_BUILDER().
-                append("#getMetadata called (imageKey / requestFormat): ").
-                append(imageKey).toString(),
+                append("#getMetadata called (imageKey / filename): ").
+                append(imageKey).append(" / ").append(fileName).toString(),
                 context);
         }
 
-        // no cache operation possible ATM => return null
-        if ((null == m_queue) || !m_cacheStatusOK.get()) {
-            return null;
-        }
-
         ImageConverterStatus status = isNotEmpty(imageKey) ?
             ImageConverterStatus.OK :
                 ImageConverterStatus.KEY_NOT_VALID;
 
         try {
+            // no cache operation possible ATM => return null
+            if ((null == m_queue) || !m_cacheStatusOK.get()) {
+                status = ImageConverterStatus.CACHE_NOT_AVAILABLE;
+                return null;
+            }
+
             final IMetadata ret = (ImageConverterStatus.OK == status) ?
                 m_queue.getMetadata(imageKey) :
                     null;
@@ -277,32 +296,43 @@ public final class ImageConverter implements IImageConverter {
         }
     }
 
-    /* (non-Javadoc)
-     * @see com.openexchange.imageconverter.api.IImageConverter#getImageAndMetadata(java.lang.String, java.lang.String, java.lang.String[])
+    /**
+     * @param imageKey
+     * @param requestFormat
+     * @param jsonInfo
+     * @param context
+     * @return
+     * @throws ImageConverterException
      */
     @Override
-    public MetadataImage getImageAndMetadata(String imageKey, String requestFormat, String... context) throws ImageConverterException {
+    public MetadataImage getImageAndMetadata(
+        String imageKey,
+        String requestFormat,
+        String fileName,
+        String... context) throws ImageConverterException {
+
         final long requestStartTime = System.currentTimeMillis();
 
         if (LOG.isTraceEnabled()) {
             implTrace(ImageConverterUtils.STR_BUILDER().
-                append("#getImageAndMetadata called (imageKey / requestFormat): ").
-                append(imageKey).append(" / ").append(requestFormat).toString(),
+                append("#getImageAndMetadata called (imageKey / requestFormat / fileName): ").
+                append(imageKey).append(" / ").append(requestFormat).append(" / ").append(fileName).toString(),
                 context);
         }
 
-        // no cache operation possible ATM => return null
-        if ((null == m_queue) || !m_cacheStatusOK.get()) {
-            return null;
-        }
-
         ImageConverterStatus status = isNotEmpty(imageKey) ?
             ImageConverterStatus.OK :
                 ImageConverterStatus.KEY_NOT_VALID;
 
         try {
+            // no cache operation possible ATM => return null
+            if ((null == m_queue) || !m_cacheStatusOK.get()) {
+                status = ImageConverterStatus.CACHE_NOT_AVAILABLE;
+                return null;
+            }
+
             final MetadataImage ret = (ImageConverterStatus.OK == status) ?
-                m_queue.getMetadataImage(imageKey, requestFormat) :
+                m_queue.getMetadataImage(imageKey, requestFormat, fileName) :
                     null;
 
             if (null == ret) {
@@ -320,32 +350,40 @@ public final class ImageConverter implements IImageConverter {
         }
     }
 
-    /*
-     * (non-Javadoc)
-     *
-     * @see com.openexchange.imageconverter.api.IImageConverter#cacheImage(java.lang.String, java.lang.String, java.io.InputStream)
+    /**
+     * @param imageKey
+     * @param inputStm
+     * @param jsonInfo
+     * @param context
+     * @throws ImageConverterException
      */
     @Override
-    public void cacheImage(final String imageKey, final InputStream inputStm, final String... context) throws ImageConverterException {
+    public void cacheImage(
+        final String imageKey,
+        final InputStream inputStm,
+        final String fileName,
+        final String... context) throws ImageConverterException {
+
         final long requestStartTime = System.currentTimeMillis();
 
         if (LOG.isTraceEnabled()) {
             implTrace("#cacheImage called for imageKey: " + imageKey, context);
         }
 
-        // no cache operation => do nothing
-        if (null == m_queue) {
-            return;
-        }
-
         ImageConverterStatus status = (isNotEmpty(imageKey) && (null != inputStm)) ?
             ImageConverterStatus.OK :
                 ImageConverterStatus.KEY_NOT_VALID;
 
         try {
+            // no cache operation => do nothing
+            if (null == m_queue) {
+                status = ImageConverterStatus.CACHE_NOT_AVAILABLE;
+                return;
+            }
+
             if (ImageConverterStatus.OK == status) {
                 // only remove entry in error case completely if cache is accesible
-                m_queue.cacheAndGetMetadataImage(imageKey, inputStm, ImageConverterPriority.BACKGROUND, null, implGetContext(context), m_cacheStatusOK.get());
+                m_queue.cacheAndGetMetadataImage(imageKey, inputStm, ImageConverterPriority.BACKGROUND, null, fileName, implGetContext(context), m_cacheStatusOK.get());
             }
         } catch (ImageConverterException e) {
             LOG.trace("IC exception while caching Image", e);
@@ -357,30 +395,50 @@ public final class ImageConverter implements IImageConverter {
         }
     }
 
-    /*
-     * (non-Javadoc)
-     *
-     * @see com.openexchange.imageconverter.api.IImageConverter#getImage(java.lang.String, java.lang.String, java.lang.String, java.io.InputStream)
+    /**
+     * @param imageKey
+     * @param requestFormat
+     * @param inputStm
+     * @param jsonInfo
+     * @param context
+     * @return
+     * @throws ImageConverterException
      */
     @Override
-    public InputStream cacheAndGetImage(final String imageKey, final String requestFormat, final InputStream inputStm, final String... context) throws ImageConverterException {
-        return cacheAndGetImage(imageKey, requestFormat, inputStm, new Mutable<>(Boolean.TRUE), context);
+    public InputStream cacheAndGetImage(
+        final String imageKey,
+        final String requestFormat,
+        final InputStream inputStm,
+        final String fileName,
+        final String... context) throws ImageConverterException {
+
+        return cacheAndGetImage(imageKey, requestFormat, inputStm, new Mutable<>(Boolean.TRUE), fileName, context);
     }
 
-    /* (non-Javadoc)
-     * @see com.openexchange.imageconverter.api.IImageConverter#cacheAndGetImageAndMetadata(java.lang.String, java.lang.String, java.io.InputStream, java.lang.String[])
+    /**
+     * @param imageKey
+     * @param requestFormat
+     * @param inputStm
+     * @param jsonInfo
+     * @param context
+     * @return
+     * @throws ImageConverterException
      */
     @Override
-    public MetadataImage cacheAndGetImageAndMetadata(String imageKey, String requestFormat, InputStream inputStm, String... context) throws ImageConverterException {
-        return cacheAndGetImageAndMetadata(imageKey, requestFormat, inputStm, new Mutable<>(Boolean.TRUE), context);
+    public MetadataImage cacheAndGetImageAndMetadata(
+        String imageKey,
+        String requestFormat,
+        InputStream inputStm,
+        final String fileName,
+        String... context) throws ImageConverterException {
+
+        return cacheAndGetImageAndMetadata(imageKey, requestFormat, inputStm, new Mutable<>(Boolean.TRUE), fileName, context);
     }
 
-    /*
-     * (non-Javadoc)
-     *
-     * @see com.openexchange.imageconverter.api.IImageConverter#clearImages()
+    /**
+     * @param context
+     * @throws ImageConverterException
      */
-    @Override
     public void clearImages(final String... context) throws ImageConverterException {
         final long requestStartTime = System.currentTimeMillis();
 
@@ -402,12 +460,10 @@ public final class ImageConverter implements IImageConverter {
         }
     }
 
-    /*
-     * (non-Javadoc)
-     *
-     * @see com.openexchange.imageconverter.api.IImageConverter#clearImagesByKey(java.lang.String)
+    /**
+     * @param imageKey
+     * @throws ImageConverterException
      */
-    @Override
     public void clearImagesByKey(String imageKey) throws ImageConverterException {
         final long requestStartTime = System.currentTimeMillis();
 
@@ -433,12 +489,11 @@ public final class ImageConverter implements IImageConverter {
         }
     }
 
-    /*
-     * (non-Javadoc)
-     *
-     * @see com.openexchange.imageconverter.api.IImageConverter#getKeyCount()
+    /**
+     * @param context
+     * @return
+     * @throws ImageConverterException
      */
-    @Override
     public long getKeyCount(final String... context) throws ImageConverterException {
         final long requestStartTime = System.currentTimeMillis();
 
@@ -453,21 +508,19 @@ public final class ImageConverter implements IImageConverter {
                 getKeyCount() :
                     getAvailable(implCreateContextProperties(context)).length;
         } catch (ImageConverterException e) {
-            LOG.trace("IC exception while getting KeyCount", e);
-
             status = ImageConverterStatus.GENERAL_ERROR;
+            LOG.trace("IC exception while getting KeyCount", e);
             throw e;
         } finally {
             implFinishRequest(RequestType.ADMIN, requestStartTime, status);
         }
     }
 
-    /*
-     * (non-Javadoc)
-     *
-     * @see com.openexchange.imageconverter.api.IImageConverter#getKeysByContext(java.lang.String)
+    /**
+     * @param context
+     * @return
+     * @throws ImageConverterException
      */
-    @Override
     public String[] getKeys(final String... context) throws ImageConverterException {
         final long requestStartTime = System.currentTimeMillis();
 
@@ -480,21 +533,19 @@ public final class ImageConverter implements IImageConverter {
         try {
             return getAvailable(implCreateContextProperties(context));
         } catch (ImageConverterException e) {
-            LOG.trace("IC exception while getting Keys", e);
-
             status = ImageConverterStatus.GENERAL_ERROR;
+            LOG.trace("IC exception while getting Keys", e);
             throw e;
         } finally {
             implFinishRequest(RequestType.ADMIN, requestStartTime, status);
         }
     }
 
-    /*
-     * (non-Javadoc)
-     *
-     * @see com.openexchange.imageconverter.api.IImageConverter#getKeyCount()
+    /**
+     * @param context
+     * @return
+     * @throws ImageConverterException
      */
-    @Override
     public long getTotalImagesSize(final String... context) throws ImageConverterException {
         final long requestStartTime = System.currentTimeMillis();
 
@@ -708,14 +759,15 @@ public final class ImageConverter implements IImageConverter {
         final String requestFormat,
         final InputStream inputStm,
         final Mutable<Boolean> usedCache,
+        final String fileName,
         final String... context) throws ImageConverterException {
 
         final long requestStartTime = System.currentTimeMillis();
 
         if (LOG.isTraceEnabled()) {
             implTrace(ImageConverterUtils.STR_BUILDER().
-                append("#cacheAndGetImage called (imageKey / requestFormat): ").
-                append(imageKey).append(" / ").append(requestFormat).toString(),
+                append("#cacheAndGetImage called (imageKey / requestFormat / fileName): ").
+                append(imageKey).append(" / ").append(requestFormat).append(" / ").append(fileName).toString(),
                 context);
         }
 
@@ -725,6 +777,7 @@ public final class ImageConverter implements IImageConverter {
 
         try {
             final byte[] inputBuffer = IOUtils.toByteArray(inputStm);
+            boolean allowDirectConversion = true;
 
             // try cache based operation first
             if ((null != m_queue) && (ImageConverterStatus.OK == status)) {
@@ -732,9 +785,9 @@ public final class ImageConverter implements IImageConverter {
                     // only remove entry in error case completely if cache is accesible
                     final InputStream bufferInputStm = new ByteArrayInputStream(inputBuffer);
                     final MetadataImage metadataImage = (null != bufferInputStm) ?
-                    m_queue.cacheAndGetMetadataImage(imageKey, bufferInputStm, ImageConverterPriority.BACKGROUND, requestFormat, implGetContext(context), m_cacheStatusOK.get()) :
+                    m_queue.cacheAndGetMetadataImage(imageKey, bufferInputStm, ImageConverterPriority.BACKGROUND, requestFormat, fileName, implGetContext(context), m_cacheStatusOK.get()) :
                         (isNotEmpty(requestFormat) ?
-                            m_queue.getMetadataImage(imageKey, requestFormat) :
+                            m_queue.getMetadataImage(imageKey, requestFormat, fileName) :
                                 null)) {
 
                     InputStream ret = (null != metadataImage) ?
@@ -752,18 +805,19 @@ public final class ImageConverter implements IImageConverter {
                 } catch (IOException | ImageConverterException e) {
                     LOG.trace("IC exception while caching and getting Image",e);
                     status = ImageConverterStatus.GENERAL_ERROR;
-                } finally {
-                    implFinishRequest(RequestType.CACHE_AND_GET, requestStartTime, status);
+
+                    if (ImageConverterUtils.NO_DIRECT_CONVERSION.equals(Throwables.getRootCause(e).getMessage())) {
+                        allowDirectConversion = false;
+                    }
                 }
             }
 
             // no cache based conversion or exception during cache based queue conversion => use on demand conversion, if possible
-            if ((null != m_imageConverterDirect) && (null != inputBuffer)) {
+            if ((null != m_imageConverterDirect) && (null != inputBuffer) && allowDirectConversion) {
                 final ImageFormat targetFormat = ImageFormat.parseImageFormat(requestFormat);
 
-                try (
-                    final InputStream bufferInputStm = new ByteArrayInputStream(inputBuffer);
-                    final MetadataImage metadataImage = m_imageConverterDirect.convert(bufferInputStm, targetFormat)) {
+                try (final InputStream bufferInputStm = new ByteArrayInputStream(inputBuffer);
+                     final MetadataImage metadataImage = m_imageConverterDirect.convert(bufferInputStm, targetFormat, fileName)) {
 
                     if (null != metadataImage) {
                         usedCache.set(Boolean.FALSE);
@@ -777,6 +831,8 @@ public final class ImageConverter implements IImageConverter {
             }
         } catch (IOException e) {
             LOG.error("IC exception while creating input buffer in #cacheAndGetImage", e);
+        } finally {
+            implFinishRequest(RequestType.CACHE_AND_GET, requestStartTime, status);
         }
 
         return null;
@@ -795,14 +851,15 @@ public final class ImageConverter implements IImageConverter {
         final String requestFormat,
         final InputStream inputStm,
         final Mutable<Boolean> usedCache,
+        final String fileName,
         final String... context) throws ImageConverterException {
 
         final long requestStartTime = System.currentTimeMillis();
 
         if (LOG.isTraceEnabled()) {
             implTrace(ImageConverterUtils.STR_BUILDER().
-                append("#cacheAndGetImageAndMetadata called (imageKey / requestFormat): ").
-                append(imageKey).append(" / ").append(requestFormat).toString(),
+                append("#cacheAndGetImageAndMetadata called (imageKey / requestFormat / fileName): ").
+                append(imageKey).append(" / ").append(requestFormat).append(" / ").append(fileName).toString(),
                 context);
         }
 
@@ -812,6 +869,7 @@ public final class ImageConverter implements IImageConverter {
 
         try {
             final byte[] inputBuffer = IOUtils.toByteArray(inputStm);
+            boolean allowDirectConversion = true;
 
             // try cache based operation first
             if ((null != m_queue) && (ImageConverterStatus.OK == status)) {
@@ -822,29 +880,31 @@ public final class ImageConverter implements IImageConverter {
                     try (final InputStream bufferInputStm = new ByteArrayInputStream(inputBuffer)) {
                         // only remove entry in error case completely if cache is accesible
                         return (null != inputBuffer) ?
-                            m_queue.cacheAndGetMetadataImage(imageKey, bufferInputStm, ImageConverterPriority.BACKGROUND, requestFormat, implGetContext(context), m_cacheStatusOK.get()) :
-                                m_queue.getMetadataImage(imageKey, requestFormat);
+                            m_queue.cacheAndGetMetadataImage(imageKey, bufferInputStm, ImageConverterPriority.BACKGROUND, requestFormat, fileName, implGetContext(context), m_cacheStatusOK.get()) :
+                                m_queue.getMetadataImage(imageKey, requestFormat, fileName);
                     }
                 } catch (ImageConverterException e) {
                     LOG.trace("IC exception while caching and getting ImageAndMetadata", e);
                     status = ImageConverterStatus.GENERAL_ERROR;
-                } finally {
-                    implFinishRequest(RequestType.CACHE_AND_GET, requestStartTime, status);
+
+                    if (ImageConverterUtils.NO_DIRECT_CONVERSION.equals(Throwables.getRootCause(e).getMessage())) {
+                        allowDirectConversion = false;
+                    }
                 }
             }
 
             // no cache based conversion or exception during cache based queue conversion => use on demand conversion, if possible
-            if ((null != m_imageConverterDirect) && (null != inputBuffer)) {
+            if ((null != m_imageConverterDirect) && (null != inputBuffer) && allowDirectConversion) {
                 final ImageFormat targetFormat = ImageFormat.parseImageFormat(requestFormat);
 
                 try (final InputStream bufferInputStm = new ByteArrayInputStream(inputBuffer)) {
-                    final MetadataImage ret = m_imageConverterDirect.convert(bufferInputStm, targetFormat);
+                    final MetadataImage metadataImage = m_imageConverterDirect.convert(bufferInputStm, targetFormat, fileName);
 
-                    if (null != ret) {
+                    if (null != metadataImage) {
                         usedCache.set(Boolean.FALSE);
                         implLogChangedCacheStatus(false);
 
-                        return ret;
+                        return metadataImage;
                     }
                 } catch (Exception e) {
                     LOG.trace("IC exception while performing on demand image conversion in #cacheAndGetImageAndMetadata", e);
@@ -852,6 +912,8 @@ public final class ImageConverter implements IImageConverter {
             }
         } catch (IOException e) {
             LOG.error("IC exception while creating input buffer in #cacheAndGetImage", e);
+        } finally {
+            implFinishRequest(RequestType.CACHE_AND_GET, requestStartTime, status);
         }
 
         return null;
@@ -934,7 +996,7 @@ public final class ImageConverter implements IImageConverter {
      */
     private static void implTrace(@NonNull final String traceMsg, final String... context) {
         LOG.trace(isNotEmpty(context) ?
-            ImageConverterUtils.IC_STR_BUILDER().append(traceMsg).append( "(Context: ").append(context[0]).append(")").toString() :
+            ImageConverterUtils.IC_STR_BUILDER().append(traceMsg).append( " (Context: ").append(context[0]).append(")").toString() :
                 traceMsg);
     }
 
