@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,8 +19,6 @@
  *
  */
 
-
-
 package com.openexchange.imageconverter.impl;
 
 import static com.openexchange.imageconverter.impl.ImageConverterUtils.LOG;
@@ -153,12 +151,6 @@ public class ImageConverterCache extends Thread {
      * @return
      * @throws ImageConverterException
      */
-    final private static String SQL_COUNT_BASED_QUERY = ImageConverterUtils.STR_BUILDER().
-        append("SELECT fc.FileStoreNumber, fc.FileStoreId, fc.SubGroupId, fc.FileId, MIN(fp.ModificationDate) AS KeyOldest").
-        append(" FROM Content_OX_IC fc INNER JOIN Properties_OX_IC fp ON fc.FileStoreNumber=fp.FileStoreNumber AND fc.FileStoreId=fp.FileStoreId").
-        append(" GROUP BY fc.SubGroupId, fc.FileId").
-        append(" ORDER BY KeyOldest ASC").toString();
-
     private int implRemoveObsoleteCountBasedKeys() throws ImageConverterException, FileItemException {
         int removedKeys = 0;
 
@@ -203,11 +195,6 @@ public class ImageConverterCache extends Thread {
      * @return
      * @throws ImageConverterException
      */
-    final private static String SQL_TIME_BASED_QUERY = ImageConverterUtils.STR_BUILDER().
-        append("SELECT fc.FileStoreNumber, fc.FileStoreId, fc.SubGroupId, fc.FileId, MIN(fp.ModificationDate) AS KeyOldest").
-        append(" FROM Content_OX_IC fc INNER JOIN Properties_OX_IC fp ON fc.FileStoreNumber=fp.FileStoreNumber AND fc.FileStoreId=fp.FileStoreId").
-        append(" WHERE fp.ModificationDate<=").toString();
-
     private int implRemoveObsoleteTimeBasedKeys() throws ImageConverterException, FileItemException {
         int removedKeys = 0;
 
@@ -251,12 +238,6 @@ public class ImageConverterCache extends Thread {
      * @return
      * @throws ImageConverterException
      */
-    final private static String SQL_SIZE_BASED_QUERY = ImageConverterUtils.STR_BUILDER().
-        append("SELECT fc.FileStoreNumber, fc.FileStoreId, fc.SubGroupId, fc.FileId, SUM(fp.Length) AS KeyLength, MIN(fp.ModificationDate) AS KeyOldest").
-        append(" FROM Content_OX_IC fc INNER JOIN Properties_OX_IC fp ON fc.FileStoreNumber=fp.FileStoreNumber AND fc.FileStoreId=fp.FileStoreId").
-        append(" GROUP BY fc.SubGroupId, fc.FileId").
-        append(" ORDER BY KeyOldest ASC").toString();
-
     private int implRemoveObsoleteSizeBasedKeys() throws ImageConverterException, FileItemException {
         int removedKeys = 0;
 
