@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,8 +19,6 @@
  *
  */
 
-
-
 package com.openexchange.imageconverter.impl;
 
 import static com.openexchange.imageconverter.impl.ImageConverterUtils.LOG;
@@ -39,6 +37,8 @@ import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
 import org.apache.commons.io.FileUtils;
+import org.apache.commons.io.FilenameUtils;
+import com.google.common.base.Throwables;
 import com.openexchange.annotation.NonNull;
 import com.openexchange.annotation.Nullable;
 import com.openexchange.imageconverter.api.FileItemException;
@@ -74,15 +74,17 @@ class ImageConverterJob implements Runnable, Closeable {
         @NonNull final String imageKey,
         @NonNull final InputStream inputStm,
         @NonNull final List<ImageFormat> imageFormats,
-        @NonNull ImageConverterQueue queue,
+        @NonNull final ImageConverterQueue queue,
+        @NonNull final String fileName,
         @Nullable final String context) throws ImageConverterException {
 
         super();
 
         m_queue = queue;
         m_imageKey = imageKey;
+        m_fileName = fileName;
         m_context = context;
-        m_inputFile = ImageConverterUtils.createTempFile();
+        m_inputFile = ImageConverterUtils.createTempFile(FilenameUtils.getExtension(fileName));
 
         if (null == m_inputFile) {
             throw new ImageConverterException("IC ConversionJob error while creating input file: " + imageKey);
@@ -154,11 +156,12 @@ class ImageConverterJob implements Runnable, Closeable {
                         append(curTargetFormat.getFormatString()).toString());
                 }
 
-                implProcessKey(curTargetFormat, true);
+                implProcessKey(curTargetFormat, m_fileName, true);
             }
         } catch (Exception e) {
             LOG.error(ImageConverterUtils.IC_STR_BUILDER().
-                append(m_imageKey).append(": ").
+                append(m_imageKey).
+                append(" (fileName: ").append(m_fileName).append("): ").
                 append((null != curTargetFormat) ? curTargetFormat.getFormatString() :"null").toString(), e);
         } finally {
             ImageConverterUtils.IC_MONITOR.incrementProcessedKeys(m_processingTime);
@@ -176,6 +179,13 @@ class ImageConverterJob implements Runnable, Closeable {
         return m_imageKey;
     }
 
+    /**
+     * @return
+     */
+    protected String getFileName() {
+        return m_fileName;
+    }
+
     /**
      *
      */
@@ -204,7 +214,7 @@ class ImageConverterJob implements Runnable, Closeable {
      * @return
      * @throws ImageConverterException
      */
-    protected boolean implProcessKey(@NonNull final ImageFormat targetFormat, final boolean isAsync) throws ImageConverterException {
+    protected boolean implProcessKey(@NonNull final ImageFormat targetFormat, @NonNull final String fileName, final boolean isAsync) throws ImageConverterException {
         ImageFormat processingFormat = m_formatsToProcess.get(targetFormat);
         final long subProcessingStartTimeMillis = System.currentTimeMillis();
         boolean ret = false;
@@ -214,7 +224,7 @@ class ImageConverterJob implements Runnable, Closeable {
             final ImageFormat referenceFormat = m_referenceFormatMap.get(targetFormat.getScaleType());
 
             if ((null != referenceFormat) && (null != (processingFormat = m_formatsToProcess.get(referenceFormat)))) {
-                ret = implCreateThumbnail(m_imageKey, m_inputFile, m_imageMetadata, referenceFormat, processingFormat, m_context, isAsync);
+                ret = implCreateThumbnail(m_imageKey, m_inputFile, m_imageMetadata, referenceFormat, processingFormat, fileName, m_context, isAsync);
 
                 if (ret) {
                     m_formatsToProcess.remove(referenceFormat);
@@ -224,10 +234,10 @@ class ImageConverterJob implements Runnable, Closeable {
             }
 
             if (ret) {
-                implCreatReferenceThumbnail(m_imageKey, m_imageMetadata, targetFormat, referenceFormat, m_context, isAsync);
+                implCreatReferenceThumbnail(m_imageKey, m_imageMetadata, targetFormat, referenceFormat, fileName, m_context, isAsync);
             }
         } else {
-            ret = implCreateThumbnail(m_imageKey, m_inputFile, m_imageMetadata, targetFormat, processingFormat, m_context, isAsync);
+            ret = implCreateThumbnail(m_imageKey, m_inputFile, m_imageMetadata, targetFormat, processingFormat, fileName, m_context, isAsync);
         }
 
         if (ret) {
@@ -244,7 +254,7 @@ class ImageConverterJob implements Runnable, Closeable {
      * @return
      * @throws ImageConverterException
      */
-    protected MetadataImage processRequestFormat(@NonNull final String requestFormat) throws ImageConverterException {
+    protected MetadataImage processRequestFormat(@NonNull final String requestFormat, @NonNull final String fileName) throws ImageConverterException {
         ImageFormat requestTargetFormat = null;
 
         try {
@@ -258,7 +268,7 @@ class ImageConverterJob implements Runnable, Closeable {
             }
 
             // no need to do anything, if requested format has already been processed, otherwise process format
-            if (!m_formatsToProcess.containsKey(requestTargetFormat) || implProcessKey(requestTargetFormat, false)) {
+            if (!m_formatsToProcess.containsKey(requestTargetFormat) || implProcessKey(requestTargetFormat, fileName, false)) {
                 return new MetadataImage(ImageConverterUtils.readImageByTargetFormat(
                     m_queue.getFileItemService(), m_imageKey, requestTargetFormat),
                     m_imageMetadata);
@@ -268,6 +278,7 @@ class ImageConverterJob implements Runnable, Closeable {
                 append(m_imageKey).
                 append(" / ").append(requestFormat).
                 append(" / ").append((null != requestTargetFormat) ? requestTargetFormat.getFormatString() : "null").
+                append(" / ").append(fileName).
                 toString(), e);
         }
 
@@ -346,8 +357,9 @@ class ImageConverterJob implements Runnable, Closeable {
 
                         LOG.trace(ImageConverterUtils.IC_STR_BUILDER().
                             append("[").append(imageDimension.width).append('x').append(imageDimension.height).append("] ").
-                            append(formatName).append(" image: ").
-                            append(imageKey).toString());
+                            append(formatName).append(" imageKey: ").append(imageKey).
+                            append(", fileName: ").append(m_fileName).
+                            toString());
                     }
                 }
             } catch (Exception e) {
@@ -385,6 +397,7 @@ class ImageConverterJob implements Runnable, Closeable {
         @NonNull final IMetadata imageMetadata,
         @NonNull final ImageFormat targetFormat,
         @NonNull final ImageFormat processingFormat,
+        @NonNull final String fileName,
         @Nullable final String context,
         final boolean isAsync) throws ImageConverterException {
 
@@ -411,16 +424,21 @@ class ImageConverterJob implements Runnable, Closeable {
 
                 LOG.trace(ImageConverterUtils.IC_STR_BUILDER().
                     append(traceMsgBuilder).
-                    append(implGetImageInformationString(imageKey, imageDimension, imageFormatShortName, targetFormatStr, usedProcessingFormat.getFormatString())).toString());
+                    append(implGetImageInformationString(imageKey, imageDimension, imageFormatShortName, targetFormatStr, usedProcessingFormat.getFormatString(), fileName)).toString());
             }
         } catch (@SuppressWarnings("unused") Exception e) {
-            final Dimension imageDimension = imageMetadata.getImageDimension();
-            final String imageFormatShortName = imageMetadata.getImageFormatName();
+            if (e.getMessage().contains("IM4Java")) {
+                LOG.info("IC does not support conversion of provided source input file for {} (fileName: {})", imageKey, fileName);
+                throw new ImageConverterException(ImageConverterUtils.NO_DIRECT_CONVERSION);
+            } else {
+                final Dimension imageDimension = imageMetadata.getImageDimension();
+                final String imageFormatShortName = imageMetadata.getImageFormatName();
 
-            LOG.error(ImageConverterUtils.IC_STR_BUILDER().
-                append("error while ").append(isAsync ? "a" : "").
-                append("synchronously creating ").append(imageFormatShortName).append(" thumbnail for ").
-                append(implGetImageInformationString(imageKey, imageDimension, imageFormatShortName, targetFormatStr, usedProcessingFormat.getFormatString())).toString());
+                LOG.error(ImageConverterUtils.IC_STR_BUILDER().
+                    append("error while ").append(isAsync ? "a" : "").
+                    append("synchronously creating ").append(imageFormatShortName).append(" thumbnail for ").
+                    append(implGetImageInformationString(imageKey, imageDimension, imageFormatShortName, targetFormatStr, usedProcessingFormat.getFormatString(), fileName)).toString());
+            }
         } finally {
             if (!ret) {
                 implRemoveFile(imageKey, targetFormatStr);
@@ -438,6 +456,7 @@ class ImageConverterJob implements Runnable, Closeable {
         @NonNull final IMetadata imageMetadata,
         @NonNull final ImageFormat targetFormat,
         @NonNull final ImageFormat referenceFormat,
+        @NonNull final String fileName,
         @Nullable final String context,
         final boolean isAsync) throws ImageConverterException {
 
@@ -459,7 +478,7 @@ class ImageConverterJob implements Runnable, Closeable {
                 LOG.trace(ImageConverterUtils.IC_STR_BUILDER().
                     append(isAsync ? "a" : "").
                     append("synchronously created reference entry for ").
-                    append(implGetImageInformationString(imageKey, imageDimension, imageFormatShortName, targetFormatStr, referenceFormatStr)).toString());
+                    append(implGetImageInformationString(imageKey, imageDimension, imageFormatShortName, targetFormatStr, referenceFormatStr, fileName)).toString());
             }
         } catch (Exception e) {
             implRemoveFile(imageKey, targetFormatStr);
@@ -470,7 +489,7 @@ class ImageConverterJob implements Runnable, Closeable {
             LOG.error(ImageConverterUtils.IC_STR_BUILDER().
                 append("error while ").append(isAsync ? "a" : "").
                 append("synchronously creating reference entry for ").
-                append(implGetImageInformationString(imageKey, imageDimension, imageFormatShortName, targetFormatStr, referenceFormatStr)).toString());
+                append(implGetImageInformationString(imageKey, imageDimension, imageFormatShortName, targetFormatStr, referenceFormatStr, fileName)).toString());
         }
     }
 
@@ -552,19 +571,24 @@ class ImageConverterJob implements Runnable, Closeable {
         final Dimension imageDimension,
         final String imageFormatShortName,
         final String targetFormatStr,
-        final String usedProcessingFormatStr) {
+        final String usedProcessingFormatStr,
+        final String fileName) {
 
         return ImageConverterUtils.STR_BUILDER().
             append("[").append(imageDimension.width).append('x').append(imageDimension.height).append("] ").
             append(imageFormatShortName).append(" image: ").
             append(imageKey).append(" / ").append(targetFormatStr).
-            append(" (Used physical format: ").append(usedProcessingFormatStr).append(')');
+            append(" (Used physical format: ").append(usedProcessingFormatStr).append(", ").
+            append("fileName: ").append(fileName).
+            append(')');
     }
 
     // - Members ---------------------------------------------------------------
 
     final private String m_imageKey;
 
+    final private String m_fileName;
+
     final private List<ImageFormat> m_imageFormats;
 
     final private ImageConverterQueue m_queue;
