@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,8 +19,6 @@
  *
  */
 
-
-
 package com.openexchange.imageconverter.impl;
 
 import static com.openexchange.imageconverter.impl.ImageConverterUtils.LOG;
@@ -363,6 +361,7 @@ class ImageConverterQueue extends Thread {
         @NonNull final InputStream srcImageStm,
         @NonNull final ImageConverterPriority priority,
         @Nullable final String requestFormat,
+        @Nullable final String fileName,
         @Nullable final String context,
         boolean removeEntryInCaseOfError) throws ImageConverterException {
 
@@ -383,9 +382,9 @@ class ImageConverterQueue extends Thread {
                 ImageConverterJob job = null;
 
                 try {
-                    job = new ImageConverterJob(imageKey, srcImageStm, m_imageFormats, this, context);
+                    job = new ImageConverterJob(imageKey, srcImageStm, m_imageFormats, this, fileName, context);
 
-                    if (hasRequestFormat && (null == (ret = job.processRequestFormat(requestFormat)))) {
+                    if (hasRequestFormat && (null == (ret = job.processRequestFormat(requestFormat, fileName)))) {
                         // resource warning has been checked => job is closed in catch block
                         throw new ImageConverterException("IC error while creating/processing new ImageConverterJob");
                     }
@@ -421,7 +420,7 @@ class ImageConverterQueue extends Thread {
                     // with UnlockMode.END_PROCESSING will happen when job is closed
                     ElementLocker.unlock(imageKey);
                 } catch (ImageConverterException e) {
-                    LOG.warn("IC removing entry after occurence of an error: {}", imageKey);
+                    LOG.info("IC removing entry after occurence of an error: {} / {}", imageKey, fileName);
 
                     if (null != job) {
                         implCloseJob(job, removeEntryInCaseOfError);
@@ -441,7 +440,7 @@ class ImageConverterQueue extends Thread {
                 } catch (ImageConverterException e) {
                     LOG.warn(ImageConverterUtils.IC_STR_BUILDER().
                         append("queue could not get MetadataImage for ").
-                        append(imageKey).append(": ").append(requestFormat).toString(),
+                        append(imageKey).append(": ").append(requestFormat).append(" / ").append(fileName).toString(),
                         Throwables.getRootCause(e));
                 }
             }
@@ -458,7 +457,7 @@ class ImageConverterQueue extends Thread {
      * @param context
      * @return
      */
-    MetadataImage getMetadataImage(@NonNull final String imageKey, @NonNull final String requestFormat) throws ImageConverterException {
+    MetadataImage getMetadataImage(@NonNull final String imageKey, @NonNull final String requestFormat, @Nullable String fileName) throws ImageConverterException {
         ImageFormat requestTargetFormat = null;
 
         try {
@@ -503,11 +502,11 @@ class ImageConverterQueue extends Thread {
                     // the job is asynchronously processed afterwards
                     if (null != queueEntry) {
                         if (trace) {
-                            LOG.trace("IC queue synchronously processes job in getMetadataImage user request: {}", imageKey);
+                            LOG.trace("IC queue synchronously processes job in getMetadataImage user request: {} / {}", imageKey, fileName);
                         }
 
                         // get MetadataImage from job directly
-                        final MetadataImage ret = queueEntry.getJob().processRequestFormat(requestFormat);
+                        final MetadataImage ret = queueEntry.getJob().processRequestFormat(requestFormat, fileName);
 
                         implSignalAvailability();
 
@@ -521,7 +520,7 @@ class ImageConverterQueue extends Thread {
             // image key is available in general, but not queued anymore =>
             // wait until outstanding job has been processed completely, if necessary
             if (trace) {
-                LOG.trace("IC queue gets image/waits for finish of asynchronous job processing in getMetadataImage user request: {}", imageKey);
+                LOG.trace("IC queue gets image/waits for finish of asynchronous job processing in getMetadataImage user request: {} / {}", imageKey, fileName);
             }
 
             ElementLocker.lock(imageKey, ElementLock.LockMode.WAIT_IF_PROCESSED);
@@ -538,6 +537,7 @@ class ImageConverterQueue extends Thread {
                 append("queue could not get MetadataImage for ").
                 append(imageKey).append(": ").
                 append(requestFormat).append(" / ").
+                append(fileName).append(" / ").
                 append((null != requestTargetFormat) ? requestTargetFormat.getFormatString() : "n/a => Removing key!").toString(),
                 Throwables.getRootCause(e));
         }
@@ -657,13 +657,14 @@ class ImageConverterQueue extends Thread {
      */
     void implCloseJob(@NonNull final ImageConverterJob job, final boolean removePersistentData) {
         final String imageKey = job.getImageKey();
+        final String fileName = job.getFileName();
 
         try {
             if (removePersistentData) {
                 m_fileItemService.removeSubGroup(ImageConverterUtils.IMAGECONVERTER_GROUPID, imageKey);
             }
         } catch (FileItemException e) {
-            LOG.trace("IC error while removing imageKey when closing Runnable: {}", imageKey, e);
+            LOG.trace("IC error while removing imageKey when closing Runnable: {} / {}", imageKey, fileName, e);
         } finally {
             // close job itself
             ImageConverterUtils.close(job);
@@ -674,7 +675,7 @@ class ImageConverterQueue extends Thread {
             }
         }
 
-        LOG.trace("IC queue closed job: {}", imageKey);
+        LOG.trace("IC queue closed job: {} / {}", imageKey, fileName);
     }
 
     // - Implementation --------------------------------------------------------
