@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,8 +19,6 @@
  *
  */
 
-
-
 package com.openexchange.imageconverter.impl;
 
 
@@ -40,5 +38,7 @@ public enum ImageConverterStatus {
 
     KEY_NOT_VALID,
 
-    KEY_NOT_AVAILABLE
+    KEY_NOT_AVAILABLE,
+
+    CACHE_NOT_AVAILABLE
 }
