@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,8 +19,6 @@
  *
  */
 
-
-
 package com.openexchange.imageconverter.impl;
 
 import java.awt.Dimension;
@@ -89,6 +87,11 @@ public class ImageConverterUtils {
      */
     public static ImageConverterMBean IC_MBEAN = null;
 
+    /**
+     * IC_METRCS
+     */
+    public static ImageConverterMetrics IC_METRICS = null;
+
     /**
      * IC_MONITOR
      */
@@ -129,6 +132,11 @@ public class ImageConverterUtils {
      */
     final public static long AWAIT_TERMINATION_TIMEOUT_MILLIS = 2000;
 
+    /**
+     * NO_DIRECT_CONVERSION
+     */
+    final public static String NO_DIRECT_CONVERSION = "NoDirectConversion";
+
     /**
      * Initializes a new {@link ImageConverterUtils}.
      */
@@ -143,6 +151,7 @@ public class ImageConverterUtils {
      */
     public static void init(@NonNull final ImageConverter imageConverter) {
         IC_MONITOR = new ImageConverterMonitoring(IC = imageConverter);
+        IC_METRICS = new ImageConverterMetrics(IC_MONITOR);
     }
 
     /**
@@ -162,8 +171,13 @@ public class ImageConverterUtils {
     /**
     * @return
     */
-    public static @Nullable File createTempFile() {
+    public static @Nullable File createTempFile(@Nullable final String extension) {
         try {
+/* KA: enable in case temp. files should be created with provided source file extension to offer more formats to be processed
+            return File.createTempFile(TEMP_COUNTER.incrementAndGet() + "oxic",
+                StringUtils.isBlank(extension) ? ".tmp" : ("." + extension),
+                ImageConverterConfig.IMAGECONVERTER_SPOOLPATH);
+*/
             return File.createTempFile(TEMP_COUNTER.incrementAndGet() + "oxic", ".tmp", ImageConverterConfig.IMAGECONVERTER_SPOOLPATH);
         } catch (IOException e) {
             LOG.error("IC can not create temp. file: {}", Throwables.getRootCause(e).getMessage());
