@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,8 +19,6 @@
  *
  */
 
-
-
 package com.openexchange.imageconverter.impl;
 
 import static com.openexchange.imageconverter.impl.ImageConverterUtils.LOG;
@@ -383,8 +381,8 @@ public class ImageProcessor {
                                 try {
                                     m_killOrphanedProcessScheduled.set(false);
                                     killOrphanedProcess(false);
-                                } catch (Exception e) {
-                                    LOG.error("IC received Exception when calling orphaned process cleanup task: " + Throwables.getRootCause(e));
+                                } catch (Exception e1) {
+                                    LOG.error("IC received Exception when calling orphaned process cleanup task: " + Throwables.getRootCause(e1));
                                 }
                             }
                         }, KILL_ORPHANED_TIMEOUT_MILLIS);
@@ -392,19 +390,17 @@ public class ImageProcessor {
 
                     return false;
                 } catch (IOException e) {
-                    rethrowable = new ImageConverterException("IC error while copying IM4Java transformation result", e);
+                    rethrowable = new ImageConverterException("IC error while performing IM4Java transformation", e);
                 }
             }
-        } catch (IM4JavaException e) {
-            rethrowable = new ImageConverterException("IC error while creating IM4Java ProcessTask", e);
-        } catch (IOException e) {
-            rethrowable = new ImageConverterException("IC error while creating IM4Java ProcessTask", e);
+        } catch (IM4JavaException | IOException e) {
+            rethrowable = new ImageConverterException("IC error while creating ProcessTask", e);
         } catch (ExecutionException e) {
-            rethrowable = new ImageConverterException("IC error while running IM4Java ProcessTask", e);
+            rethrowable = new ImageConverterException("IC execution error while running ProcessTask", e);
         } catch (@SuppressWarnings("unused") InterruptedException e) {
-            LOG.trace("IC interrupted while running IM4Java ProcessTask");
+            LOG.trace("IC ProcessTask interrupted");
         } catch (@SuppressWarnings("unused") RejectedExecutionException e) {
-            LOG.trace("IC rejected execution while running IM4Java ProcessTask");
+            LOG.trace("IC ProcessTask rejected");
         } finally {
             FileUtils.deleteQuietly(tmpOutputDir);
         }
