@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,8 +19,6 @@
  *
  */
 
-
-
 package com.openexchange.imagemetadata.impl;
 
 import java.awt.Dimension;
@@ -72,7 +70,7 @@ public class MetadataReaderImpl implements IMetadataReader {
         }
 
         try {
-            ret = new MetadataImpl(ImageMetadataReader.readMetadata(new BufferedInputStream(mediaInputStm), false));
+            ret = new MetadataImpl(ImageMetadataReader.readMetadata(new BufferedInputStream(mediaInputStm)));
         } catch (Throwable e) {
             throw new MetadataException(e);
         }
@@ -112,10 +110,11 @@ public class MetadataReaderImpl implements IMetadataReader {
      */
     @Override
     public IMetadata readMetadata(JSONObject jsonMetadata) throws MetadataException {
-        return implUpdateMetadataHeader(new MetadataImpl(
-            (null != jsonMetadata) ?
-                jsonMetadata :
-                    new JSONObject()), null);
+        if (null == jsonMetadata) {
+            throw new MetadataException(new MetadataException("Argument must not be null"));
+        }
+
+        return implUpdateMetadataHeader(new MetadataImpl(jsonMetadata), null);
     }
 
     // - Implementation --------------------------------------------------------
